@@ -19,6 +19,10 @@ def file_exists(path: str) -> bool:
     return os.path.exists(path)
 
 
+def file_remove(path: str) -> None:
+    os.remove(path)
+
+
 def write_csv_data(path: str, header: List[str], data: List[Any], update_type: str = "w", as_bz2: bool = False) -> None:
     if as_bz2:
         with bz2.open(filename=path, mode="wt") as f:
